Module log

Module log 

Available on crate feature tracing only.

Macros

debug
Constructs an event at the debug level.
error
Constructs an event at the error level.
info
Constructs an event at the info level.
trace
Constructs an event at the trace level.
warn
Constructs an event at the warn level.

Functions

tracing_init
A convenient function to initialize tracing with a default configuration.
tracing_try_init
A convenient function to initialize tracing with a default configuration.