PluginHandler

Struct PluginHandler 

pub struct PluginHandler<A: PluginApp> { /* private fields */ }
Example

PluginHandler::builder()
    .name("Test Plugin")
    .description("A test plugin for Everything")
    .author("Chaoses-Ib")
    .version("0.1.0")
    .link("https://github.com/Chaoses-Ib/IbEverythingLib")
    .options_pages(vec![
        OptionsPage::builder()
            .name("Test Plugin")
            .load(ui::winio::spawn::<options::MainModel>)
            .build(),
    ])
    .build()

Design

  • Config may be accessed from multiple threads, and options pages need to modify it. To avoid race conditions, either config is cloned when modifying, and then PluginApp is reloaded with it, i.e. [arc_swap::ArcSwap]; or PluginApp is shutdown before modifying and then restarted.
  • User defined static to work around generic static limit.
    • Interior mutability to make it easy to use with static. But UnsafeCell to avoid cost.

Config lifetime:

Implementations

Source

impl<A: PluginApp> PluginHandler<A>

Source

impl<A: PluginApp> PluginHandler<A>

pub fn load_settings(&self, data: *mut c_void) -> Option<A::Config>

pub fn save_settings(&self, data: *mut c_void) -> *mut c_void

Source

impl<A: PluginApp> PluginHandler<A>

pub fn add_options_pages(&self, data: *mut c_void) -> *mut c_void

pub fn load_options_page(&self, data: *mut c_void) -> *mut c_void

Evertyhing only loads a options page when the user selects it

TODO: tooltip_hwnd

pub fn load_options_page_winio<'a, T: OptionsPageComponent<'a>>( &self, data: *mut c_void, ) -> *mut c_void

Available on crate feature winio only.
pub fn save_options_page(&self, data: *mut c_void) -> *mut c_void

pub fn get_options_page_minmax(&self, _data: *mut c_void) -> *mut c_void

pub fn size_options_page(&self, _data: *mut c_void) -> *mut c_void

pub fn options_page_proc(&self, data: *mut c_void) -> *mut c_void

pub fn kill_options_page(&self, data: *mut c_void) -> *mut c_void

Source

impl<A: PluginApp> PluginHandler<A>

pub fn builder() -> PluginHandlerBuilder<A>

Create an instance of PluginHandler using the builder syntax

Source

impl<A: PluginApp> PluginHandler<A>

pub fn init_start(&self)

Panics if already initialized.

pub fn init_start_with_config(&self, config: A::Config)

Panics if already initialized.

pub fn stop_kill(&self)

Panics if not initialized or already stopped.

pub fn get_host(&self) -> Option<&PluginHost>

None before handling EVERYTHING_PLUGIN_PM_INIT

pub fn host(&self) -> &PluginHost

Not available before handling EVERYTHING_PLUGIN_PM_INIT

pub fn handle_init_i18n(_msg: u32, _data: *mut c_void)

Should be called before PluginHandler is created, as some fields may depend on the locale.

Already called in the plugin_main! macro. (Requiring manually calling is a footgun: IbEverythingExt #100)

pub fn handle(&self, msg: u32, data: *mut c_void) -> *mut c_void

You shouldn’t and unlikely need to call this function from multiple threads.

pub fn instance_name(&self) -> Option<&str>

pub unsafe fn app(&self) -> &A

Not available during saving config and recreated afterwards. Use Self::with_app instead when possible.

pub fn with_app<T>(&self, f: impl FnOnce(&A) -> T) -> T

Not available during saving config.