Child

Struct Child 

pub struct Child<T>
where T: Component,
{ /* private fields */ }
Available on crate feature winio only.
Helper to embed one component into another. It handles different types of messages and events.

Implementations

Source

impl<T> Child<T>
where T: Component,

pub async fn init<'a>( init: impl Into<<T as Component>::Init<'a>>, ) -> Result<Child<T>, <T as Component>::Error>

Create and initialize the child component.

pub async fn start<C>( &mut self, sender: &ComponentSender<C>, f: impl FnMut(<T as Component>::Event) -> Option<<C as Component>::Message>, propagate: impl FnMut() -> <C as Component>::Message, ) -> !
where C: Component,

Start to receive and interp the events of the child component.

Define a root component MainModel, and it contains a window: Child<Window>. The message of MainModel is defined as

enum MainMessage {
    Noop,
    Close,
}

In the MainModel::start, you should write

async fn start(&mut self, sender: &ComponentSender<Self>) -> ! {
    start! {
        sender, default: MainMessage::Noop,
        self.window => {
            WindowEvent::Close => MainMessage::Close,
        },
        // ...other children
    }
}

It is equivalent to

async fn start(&mut self, sender: &ComponentSender<Self>) -> ! {
    let fut_window = self.window.start(
        sender,
        |e| match e {
            WindowEvent::Close => Some(MainMessage::Close),
            // ignore other events
            _ => None,
        },
        // you should always propagate internal messages
        || MainMessage::Noop,
    );
    // ...other children
    futures_util::join!(fut_window, /* ... */);
}
pub fn post(&mut self, message: <T as Component>::Message)

Post message to the child component.

pub async fn emit( &mut self, message: <T as Component>::Message, ) -> Result<bool, <T as Component>::Error>

Emit message to the child component.

pub async fn update(&mut self) -> Result<bool, <T as Component>::Error>

Respond to the child message.

pub fn render(&mut self) -> Result<(), <T as Component>::Error>

Render the child component.

pub fn sender(&self) -> &ComponentSender<T>

Get the sender of the child component.

pub async fn try_into_root(self) -> Result<Root<T>, <T as Component>::Error>

Try to convert the child component into a root component.

It clears the inner message cache and updates the child component if needed.

Source

impl<T> Child<T>
where T: Component + 'static,

pub fn into_boxed( self, ) -> Child<BoxComponent<<T as Component>::Message, <T as Component>::Event, <T as Component>::Error>>

Box the component.