Window

Struct Window 

pub struct Window { /* private fields */ }
Available on crate feature winio only.
A simple window.

Platform specific

  • Qt: The desctruct order of Qt requires the window to be dropped last, and you should better put it at the end of the struct.

Implementations

Source

impl Window

pub fn client_size(&self) -> Result<Size2D<f64, LogicalSpace>, Error>

The inner client size.

pub fn set_icon_by_id(&mut self, id: u16) -> Result<(), Error>

Available on Windows only.

Set window icon by resource ID.

pub fn style(&self) -> Result<u32, Error>

Available on win32 only.

Get window style.

pub fn set_style(&mut self, s: u32) -> Result<(), Error>

Available on win32 only.

Set window style.

pub fn ex_style(&self) -> Result<u32, Error>

Available on win32 only.

Get window extended style.

pub fn set_ex_style(&mut self, s: u32) -> Result<(), Error>

Available on win32 only.

Set window extended style.

pub fn backdrop(&self) -> Result<Backdrop, Error>

Available on Windows only.

Get the backdrop effect of the window.

Returns an error if the platform does not support it.

Platform specific
  • Win32: Supported on Windows 11 22H2 and later; some controls might look weird.
  • WinUI: Supported on 1.3 and later; the color of the title bar might be different from the client area.
pub fn set_backdrop(&mut self, backdrop: Backdrop) -> Result<(), Error>

Available on Windows only.

Set the backdrop effect of the window.