pub trait __IntoArray<T> {
type Output: Len;
// Required method
fn into_array(self) -> Self::Output;
}Available on crate feature
winio only.Expand description
Converts a tuple into an array, where the fields of the tuple can be converted into the same type of the array element.
Required Associated Types
Required Methods
fn into_array(self) -> Self::Output
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".