pub struct Window { /* private fields */ }Available on crate feature
winio only.Expand description
A simple window.
Platform specific
- Qt: The desctruct order of Qt requires the window to be dropped last, and you should better put it at the end of the struct.
Implementations
Sourceimpl Window
impl Window
Sourcepub fn client_size(&self) -> Result<Size2D<f64, LogicalSpace>, Error>
pub fn client_size(&self) -> Result<Size2D<f64, LogicalSpace>, Error>
The inner client size.
Sourcepub fn set_icon_by_id(&mut self, id: u16) -> Result<(), Error>
Available on Windows only.
pub fn set_icon_by_id(&mut self, id: u16) -> Result<(), Error>
Set window icon by resource ID.
Sourcepub fn set_style(&mut self, s: u32) -> Result<(), Error>
Available on win32 only.
pub fn set_style(&mut self, s: u32) -> Result<(), Error>
win32 only.Set window style.
Sourcepub fn ex_style(&self) -> Result<u32, Error>
Available on win32 only.
pub fn ex_style(&self) -> Result<u32, Error>
win32 only.Get window extended style.
Sourcepub fn set_ex_style(&mut self, s: u32) -> Result<(), Error>
Available on win32 only.
pub fn set_ex_style(&mut self, s: u32) -> Result<(), Error>
win32 only.Set window extended style.
Sourcepub fn backdrop(&self) -> Result<Backdrop, Error>
Available on Windows only.
pub fn backdrop(&self) -> Result<Backdrop, Error>
Get the backdrop effect of the window.
Returns an error if the platform does not support it.
Platform specific
- Win32: Supported on Windows 11 22H2 and later; some controls might look weird.
- WinUI: Supported on 1.3 and later; the color of the title bar might be different from the client area.